@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc.c
- * Version    : $Id: ipv6calc.c,v 1.25 2006/08/06 12:44:13 peter Exp $
- * Copyright  : 2001-2006 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calc.c,v 1.29 2007/02/06 07:04:33 peter Exp $
+ * Copyright  : 2001-2007 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
@@ -38,15 +38,25 @@
 
 long int ipv6calc_debug = 0;
 
+/* anonymization default values */
+int mask_ipv4 = 24;
+int mask_iid = 1;
+
 #ifdef SUPPORT_IP2LOCATION
-int  use_ip2location = 0; /* if set to 1, IP2Location is enabled by option(s) */
-char file_ip2location[NI_MAXHOST] = "";
+int  use_ip2location_ipv4 = 0; /* if set to 1, IP2Location IPv4 is enabled by option(s) */
+int  use_ip2location_ipv6 = 0; /* if set to 1, IP2Location IPv6 is enabled by option(s) */
+char file_ip2location_ipv4[NI_MAXHOST] = "";
+char file_ip2location_ipv6[NI_MAXHOST] = "";
 #endif
 
 #ifdef SUPPORT_GEOIP
 int  use_geoip = 0; /* if set to 1, GeoIP is enabled by option(s) */
+#ifdef GEOIP_DEFAULT_FILE
+char file_geoip[NI_MAXHOST] = GEOIP_DEFAULT_FILE;
+#else
 char file_geoip[NI_MAXHOST] = "";
 #endif
+#endif
 
 void printversion(void) {
 	fprintf(stderr, "%s: version %s\n", PROGRAM_NAME, PACKAGE_VERSION);
@@ -118,20 +128,31 @@ int main(int argc,char *argv[]) {
 				ipv6calc_debug = atol(optarg);
 				break;
 
-			case 'p':
+			case DB_ip2location_ipv4:
 #ifdef SUPPORT_IP2LOCATION
 				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got IP2Location database file: %s\n", DEBUG_function_name, optarg);
+					fprintf(stderr, "%s: Got IP2Location IPv4 database file: %s\n", DEBUG_function_name, optarg);
 				};
-				strncpy(file_ip2location, optarg, sizeof(file_ip2location) -1 );
-				use_ip2location = 1;
+				strncpy(file_ip2location_ipv4, optarg, sizeof(file_ip2location_ipv4) -1 );
+				use_ip2location_ipv4 = 1;
 #else
-				fprintf(stderr, " Support for option -p <path to IP2Location database> not compiled in, IP2Location support disabled\n");
+				fprintf(stderr, " Support for option '--db-ip2location-ipv4 <IP2Location IPv4 database file>' not compiled in, IP2Location support disabled\n");
 #endif
-			
 				break;
 
-			case 'g':
+			case DB_ip2location_ipv6:
+#ifdef SUPPORT_IP2LOCATION
+				if (ipv6calc_debug != 0) {
+					fprintf(stderr, "%s: Got IP2Location IPv6 database file: %s\n", DEBUG_function_name, optarg);
+				};
+				strncpy(file_ip2location_ipv6, optarg, sizeof(file_ip2location_ipv6) -1 );
+				use_ip2location_ipv6 = 1;
+#else
+				fprintf(stderr, " Support for option '--db-ip2location-ipv6 <IP2Location IPv6 database file>' not compiled in, IP2Location support disabled\n");
+#endif
+				break;
+
+			case DB_geoip:
 #ifdef SUPPORT_GEOIP
 				if (ipv6calc_debug != 0) {
 					fprintf(stderr, "%s: Got GeoIP database file: %s\n", DEBUG_function_name, optarg);
@@ -139,11 +160,19 @@ int main(int argc,char *argv[]) {
 				strncpy(file_geoip, optarg, sizeof(file_geoip) -1 );
 				use_geoip = 1;
 #else
-				fprintf(stderr, " Support for option -g <path to GeoIP database> not compiled in, GeoIP support disabled\n");
+				fprintf(stderr, " Support for option '--db-geoip <GeoIP database file>' not compiled in, GeoIP support disabled\n");
 #endif
-			
 				break;
 
+			case 'G':
+#ifdef GEOIP_DEFAULT_FILE
+				use_geoip = 1;
+#else
+				fprintf(stderr, " Support for option '--db-geoip-default|-G' not compiled in, GeoIP support disabled\n");
+#endif
+				break;
+
+
 			case CMD_printexamples:
 				command = CMD_printexamples;
 				break;
@@ -252,6 +281,23 @@ int main(int argc,char *argv[]) {
 				command = CMD_showinfotypes;
 				break;
 
+			case CMD_ANON_NO_MASK_IID:
+				mask_iid = 0;
+				break;
+
+			case CMD_ANON_MASK_IPV4:
+				mask_ipv4 = atoi(optarg);
+				if (mask_ipv4 < 0 || mask_ipv4 > 32) {
+					fprintf(stderr, " value for option 'mask-ipv4' out-of-range  [0-32]\n");
+					exit(EXIT_FAILURE);
+				};
+				break;
+
+			case CMD_ANON_PRESET_STANDARD:
+				mask_ipv4 = 24;
+				mask_iid = 1;
+				break;
+
 			/* format options */
 			case 'C':
 			case FORMATOPTION_NUM_printcompressed + FORMATOPTION_NUM_HEAD:
@@ -782,8 +828,10 @@ int main(int argc,char *argv[]) {
 		} else if ( (inputtype == FORMAT_mac) && (action == ACTION_mac_to_eui64) ) {
 			outputtype = FORMAT_eui64;
 			formatoptions |= FORMATOPTION_printfulluncompressed;
-		} else if ( (inputtype == FORMAT_ipv6addr) && (action == ACTION_undefined) ) {
+		} else if ( (inputtype == FORMAT_ipv6addr) && ( (action == ACTION_undefined) || (action == ACTION_anonymize) ) ) {
 			outputtype = FORMAT_ipv6addr;
+		} else if ( (inputtype == FORMAT_ipv4addr) && (action == ACTION_anonymize) ) {
+			outputtype = FORMAT_ipv4addr;
 		} else if ( ((inputtype == FORMAT_ipv4addr) || (inputtype == FORMAT_ipv4hex) || (inputtype == FORMAT_ipv4revhex)) && (action == ACTION_undefined) ) {
 			outputtype = FORMAT_ipv4addr;
 		};
@@ -844,6 +892,27 @@ int main(int argc,char *argv[]) {
 				exit(EXIT_FAILURE);
 			};
 			break;
+
+		case ACTION_anonymize:
+			if (inputtype == FORMAT_ipv4addr && outputtype == FORMAT_ipv4addr) {
+				/* anonymize IPv4 address */
+				if (ipv4addr.flag_valid != 1) {
+					fprintf(stderr, "No valid IPv4 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+				libipv4addr_anonymize(&ipv4addr, mask_ipv4);
+			} else if (inputtype == FORMAT_ipv6addr && outputtype == FORMAT_ipv6addr) {
+				/* anonymize IPv6 address */
+				if (ipv6addr.flag_valid != 1) {
+					fprintf(stderr, "No valid IPv6 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+				libipv6addr_anonymize(&ipv6addr, mask_iid, mask_ipv4);
+			} else {
+				fprintf(stderr, "Unsupported anonymization!\n");
+				exit(EXIT_FAILURE);
+			};
+			break;
 			
 		case ACTION_iid_token_to_privacy:
 			if (ipv6addr.flag_valid != 1 || ipv6addr2.flag_valid != 1) {
