@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : showinfo.c
- * Version    : $Id: showinfo.c,v 1.29 2006/08/07 21:33:13 peter Exp $
- * Copyright  : 2001-2006 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: showinfo.c,v 1.36 2007/03/03 11:57:29 peter Exp $
+ * Copyright  : 2001-2007 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Function to show information about a given IPv6 address
@@ -12,7 +12,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#include "showinfo.h"
 #include "ipv6calc.h"
 #include "libipv6calc.h"
 #include "libipv6calcdebug.h"
@@ -25,11 +24,22 @@
 #include "libeui64.h"
 #include "libeui64.h"
 #include "config.h"
+#include "showinfo.h"
 
 #ifdef SUPPORT_IP2LOCATION
 #include "IP2Location.h"
-extern int use_ip2location;
-extern char file_ip2location[NI_MAXHOST];
+
+/* 
+ * API_VERSION is defined as a bareword in IP2Location.h, 
+ * we need this trick to stringify it. Blah.
+ */
+#define makestr(x) #x
+#define xmakestr(x) makestr(x)
+
+extern int use_ip2location_ipv4;
+extern int use_ip2location_ipv6;
+extern char file_ip2location_ipv4[NI_MAXHOST];
+extern char file_ip2location_ipv6[NI_MAXHOST];
 #endif
 
 #ifdef SUPPORT_GEOIP
@@ -120,21 +130,31 @@ static void printfooter(const uint32_t formatoptions) {
 #ifdef SUPPORT_IP2LOCATION
 /* print IP2Location information */
 #define DEBUG_function_name "showinfo/print_ip2location"
-static void print_ip2location(const char *addrstring, const uint32_t formatoptions, const char *additionalstring) {
+static void print_ip2location(const char *addrstring, const uint32_t formatoptions, const char *additionalstring, int version) {
 
 	static int flag_ip2location_info_shown = 0;
 
 	uint32_t machinereadable = (formatoptions & FORMATOPTION_machinereadable);
 	char tempstring[NI_MAXHOST] = "";
+	char *file_ip2location;
+
+	if (version == 4) {
+		file_ip2location = file_ip2location_ipv4;
+	} else if (version == 6) {
+		file_ip2location = file_ip2location_ipv6;
+	} else {
+		fprintf(stderr, " IP2LOCATION version %d not supported\n", version);
+		return;
+	};
 
 	if (strlen(file_ip2location) == 0) {
 		/* no file given, nothing more todo */
-		fprintf(stderr, " IP2LOCATION database file not given\n");
+		fprintf(stderr, " IP2LOCATION IPv%d database file not given\n", version);
 		return;
 	};
 
 	if ( (ipv6calc_debug & DEBUG_showinfo) != 0 ) {
-		fprintf(stderr, "%s: IP2LOCATION try to open database: %s\n", DEBUG_function_name, file_ip2location);
+		fprintf(stderr, "%s: IP2LOCATION try to open IPv%d database: %s\n", DEBUG_function_name, version, file_ip2location);
 	};
 
 	IP2Location *IP2LocationObj = IP2Location_open(file_ip2location);
@@ -155,7 +175,13 @@ static void print_ip2location(const char *addrstring, const uint32_t formatoptio
 		flag_ip2location_info_shown = 1;
 
 		if ( machinereadable != 0 ) {
-			snprintf(tempstring, sizeof(tempstring) - 1, "IP2LOCATION_DATABASE_INFO=url=http://www.ip2location.com date=%04d-%02d-%02d entries=%d", IP2LocationObj->databaseyear + 2000, IP2LocationObj->databasemonth + 1, IP2LocationObj->databaseday, IP2LocationObj->databasecount);
+			snprintf(tempstring, sizeof(tempstring) - 1, \
+				"IP2LOCATION_DATABASE_INFO=url=http://www.ip2location.com date=%04d-%02d-%02d entries=%d apiversion=%s", \
+				IP2LocationObj->databaseyear + 2000, \
+				IP2LocationObj->databasemonth + 1, \
+				IP2LocationObj->databaseday, \
+				IP2LocationObj->databasecount, \
+				xmakestr(API_VERSION));
 			printout(tempstring);
 		};
 	};
@@ -307,7 +333,7 @@ static void print_geoip(const char *addrstring, const uint32_t formatoptions, co
 			flag_geoip_info_shown = 1;
 
 			if ( machinereadable != 0 ) {
-				snprintf(tempstring, sizeof(tempstring) - 1, "GEOIP_DATABASE_INFO=%s", GeoIP_database_info(gi));
+				snprintf(tempstring, sizeof(tempstring) - 1, "GEOIP_DATABASE_INFO=%s apiversion=system", GeoIP_database_info(gi));
 				printout(tempstring);
 			};
 		};
@@ -342,7 +368,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		fprintf(stderr, "Error converting IPv4 address: %s\n", tempipv4string);
 	};
 
-	if (formatoptions & FORMATOPTION_printembedded) {
+	if ((formatoptions & FORMATOPTION_printembedded) != 0) {
 		snprintf(embeddedipv4string, sizeof(embeddedipv4string) - 1, "[%s]", tempipv4string);
 	};
 	
@@ -380,8 +406,8 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 
 #ifdef SUPPORT_IP2LOCATION
 	/* IP2Location information */
-	if (use_ip2location == 1) {
-		print_ip2location(tempipv4string, formatoptions, embeddedipv4string);
+	if (use_ip2location_ipv4 == 1) {
+		print_ip2location(tempipv4string, formatoptions, embeddedipv4string, 4);
 	};
 #endif
 
@@ -663,8 +689,8 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 			ipv4addr_setoctett(&ipv4addr2, (unsigned int) i, (unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) 4 + i));
 		};
 
-		print_ipv4addr(&ipv4addr, formatoptions | FORMATOPTION_printembedded, "TEREDO-SERVER");
-		print_ipv4addr(&ipv4addr2, formatoptions | FORMATOPTION_printembedded, "TEREDO-CLIENT");
+		print_ipv4addr(&ipv4addr, formatoptions | FORMATOPTION_printembedded, "TEREDO-CLIENT");
+		print_ipv4addr(&ipv4addr2, formatoptions | FORMATOPTION_printembedded, "TEREDO-SERVER");
 
 		retval = libipv4addr_ipv4addrstruct_to_string(&ipv4addr, helpstring, 0);
 		if ( retval != 0 ) {
@@ -674,13 +700,13 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 		};	
 
 		/* extract Teredo client UDP port */
-		port = ((unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) 10) << 8 | (unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) 11)) ^ 0xffff;
+		port = (uint16_t) (((uint16_t) ipv6addr_getoctett(ipv6addrp, (unsigned int) 10) << 8 | (uint16_t) ipv6addr_getoctett(ipv6addrp, (unsigned int) 11)) ^ 0xffff);
 
 		if ( machinereadable != 0 ) {
-			snprintf(tempstring, sizeof(tempstring) - 1, "TEREDO_PORT_CLIENT=%d", port);
+			snprintf(tempstring, sizeof(tempstring) - 1, "TEREDO_PORT_CLIENT=%u", (unsigned int) port);
 			printout(tempstring);
 		} else {
-			fprintf(stdout, "Address type is Teredo and included IPv4 server address is: %s and client port: %d\n", helpstring, port);
+			fprintf(stdout, "Address type is Teredo and included IPv4 server address is: %s and client port: %u\n", helpstring, (unsigned int) port);
 		};
 
 		/* get registry string */
@@ -832,13 +858,8 @@ END:
 
 #ifdef SUPPORT_IP2LOCATION
 	/* IP2Location information */
-	if (use_ip2location == 1) {
-		/* C-API at least version 1.1.0 currently doesn't support IPv6, while related database is available */
-		if ((formatoptions & FORMATOPTION_quiet) == 0) {
-			fprintf(stderr, "%s: IP2Location C-API currently misses support of IPv6\n", DEBUG_function_name);
-		};
-
-		// print_ip2location(ipv6addrstring, formatoptions, "");
+	if (use_ip2location_ipv6 == 1) {
+		print_ip2location(ipv6addrstring, formatoptions, "", 6);
 	};
 #endif
 
@@ -871,7 +892,7 @@ END:
 int showinfo_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t formatoptions) {
 	int retval = 1;
 
-	print_ipv4addr(ipv4addrp, formatoptions, NULL);
+	print_ipv4addr(ipv4addrp, formatoptions, "");
 
 	printfooter(formatoptions);
 	retval = 0;
