@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calccommands.h
- * Version    : $Id: ipv6calccommands.h,v 1.1 2002/04/21 11:31:25 peter Exp $
+ * Version    : $Id: ipv6calccommands.h,v 1.4 2007/02/06 07:08:26 peter Exp $
  * Copyright  : 2002 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -45,4 +45,15 @@
 #define CMD_showinfo			0x001001
 #define CMD_showinfotypes		0x001002
 
+/* database options */
+#define DB_ip2location_ipv4		0x002001
+#define DB_ip2location_ipv6		0x002002
+#define DB_geoip			0x002011
+
+/* address anonymizer options */
+#define CMD_ANON_PRESET_STANDARD	0x003001
+#define CMD_ANON_MASK_IPV4		0x003010
+#define CMD_ANON_NO_MASK_IID		0x003011
+
+
 #endif
