@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calcoptions.h
- * Version    : $Id: ipv6calcoptions.h,v 1.10 2006/08/06 12:44:14 peter Exp $
+ * Version    : $Id: ipv6calcoptions.h,v 1.13 2007/02/06 07:08:26 peter Exp $
  * Copyright  : 2002-2006 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -33,17 +33,19 @@
  *  m = output machine readable
  *  i = showinfo
  *  q = be more quiet
- *  p <path to IP2Location file> = path to IP2Location database file
- *  g <path to GeoIP file> = path to GeoIP database file
  */
-/*@unused@*/ static char *ipv6calc_shortopts = "vh?p:g:rmabd:iulqUFCI:O:A:";
+/*@unused@*/ static char *ipv6calc_shortopts = "vh?rmabd:iulqGUFCI:O:A:";
 
 /* define long options */
 /*@unused@*/ static struct option ipv6calc_longopts[] = {
 	{"version", 0, 0, (int) 'v'},
 	{"debug", 1, 0, (int) 'd'},
-	{"path", 1, 0, (int) 'p'},
-	{"path-geoip", 1, 0, (int) 'g'},
+
+	/* database options */
+	{"db-ip2location-ipv4", 1, 0, DB_ip2location_ipv4},
+	{"db-ip2location-ipv6", 1, 0, DB_ip2location_ipv6},
+	{"db-geoip", 1, 0, DB_geoip},
+	{"db-geoip-default", 1, 0, (int) 'G'},
 
 	/* help options */
 	{"help", 0, 0, (int) 'h'},
@@ -108,6 +110,11 @@
 	
 	{ "printmirrored"        , 0, 0, FORMATOPTION_NUM_printmirrored + FORMATOPTION_NUM_HEAD },
 
+	/* address anonymizer options */
+	{ "anonymize-standard" , 0, 0, CMD_ANON_PRESET_STANDARD },
+	{ "mask-ipv4" , 1, 0, CMD_ANON_MASK_IPV4 },
+	{ "no-mask-iid" , 0, 0, CMD_ANON_NO_MASK_IID },
+
 	/* new options */
 	{ "in"        , 1, 0, CMD_inputtype  },
 	{ "out"       , 1, 0, CMD_outputtype },
